summaryrefslogtreecommitdiffstats
path: root/src/H5Edefin.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5Edefin.h')
-rw-r--r--src/H5Edefin.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/H5Edefin.h b/src/H5Edefin.h
index a09db35..1e1730e 100644
--- a/src/H5Edefin.h
+++ b/src/H5Edefin.h
@@ -179,7 +179,8 @@ hid_t H5E_CANTRESIZE_g = FAIL; /* Unable to resize a metadata cache ent
hid_t H5E_CANTDEPEND_g = FAIL; /* Unable to create a flush dependency */
hid_t H5E_CANTUNDEPEND_g = FAIL; /* Unable to destroy a flush dependency */
hid_t H5E_CANTNOTIFY_g = FAIL; /* Unable to notify object about action */
-hid_t H5E_LOGFAIL_g = FAIL; /* Failure in the cache logging framework */
+hid_t H5E_LOGGING_g = FAIL; /* Failure in the cache logging framework */
+hid_t H5E_LOGFAIL_g = FAIL; /* old H5E_LOGGING_g (maintained for binary compatibility) */
hid_t H5E_CANTCORK_g = FAIL; /* Unable to cork an object */
hid_t H5E_CANTUNCORK_g = FAIL; /* Unable to uncork an object */